@@ -8,17 +8,17 @@ use Storable 3.15 qw(dclone);
 
 use namespace::autoclean;
 
-use Data::Printer;
+# use Data::Printer;
 
 no warnings 'experimental';
 
-our $VERSION='0.016';
+our $VERSION='0.017';
 
 =head1 NAME
 
 Vote::Count::Redact
 
-=head1 VERSION 0.016
+=head1 VERSION 0.017
 
 Methods for Redacting Ballots.
 
